@@ -488,7 +488,8 @@ def _cc_compiler(compiler_exe="cc"):
         compiler = "clang" if "clang" in out else "gcc"
         # clang and gcc have version after a space, first try to find that to skip extra numbers
         # that might appear in the first line of the output before the version
-        # There might also be a leading parenthesis that contains build information, so we try to skip it
+        # There might also be a leading parenthesis that contains build information,
+        # so we try to skip it
         installed_version = re.search(r"(?:\(.*\))? ([0-9]+(\.[0-9]+)*)", out)
         # Fallback to the first number we find optionally followed by other version fields
         installed_version = installed_version or re.search(r"([0-9]+(\.[0-9]+)*)", out)
@@ -532,7 +533,7 @@ def detect_intel_compiler(compiler_exe="icx"):
     try:
         ret, out = detect_runner(f'"{compiler_exe}" --version')
         if ret != 0:
-            return None, None
+            return None, None, None
         compiler = "intel-cc"
         installed_version = re.search(r"(202[0-9]+(\.[0-9])?)", out).group()
         if installed_version:
