@@ -15,7 +15,7 @@ from conan.errors import ConanException
 from conan.api.model import PkgReference
 from conan.api.model import RecipeReference
 from conan.internal.util.dates import revision_timestamp_now
-from conan.internal.util.files import rmdir, renamedir, mkdir
+from conan.internal.util.files import rmdir, renamedir, mkdir, atomic_replace
 
 
 class PkgCache:
@@ -110,6 +110,9 @@ class PkgCache:
 
     def recipe_layout(self, ref: RecipeReference):
         """ the revision must exists, the folder must exist
+        The regular graph building will use this method if the revision is defined, like
+        when using lockfiles or explicit, or recipe_layout_latest() if not, to do one single DB
+        query
         """
         assert ref.revision is not None
         ref_data = self._db.get_recipe(ref)
@@ -117,6 +120,17 @@ class PkgCache:
         ref = ref_data.get("ref")  # new revision with timestamp
         return RecipeLayout(ref, os.path.join(self._base_folder, ref_path))
 
+    def recipe_layout_latest(self, ref: RecipeReference):
+        """ the revision must be None, the folder must exist
+        This method was added so the ConanProxy used to resolve the dependency graph
+        avoid doing 2 DB calls when the revision is not defined
+        """
+        assert ref.revision is None
+        ref_data = self._db.get_latest_recipe(ref)
+        ref_path = ref_data.get("path")
+        ref = ref_data.get("ref")  # new revision with timestamp
+        return RecipeLayout(ref, os.path.join(self._base_folder, ref_path))
+
     def get_latest_recipe_revision(self, ref: RecipeReference) -> RecipeReference:
         assert ref.revision is None
         ref_data = self._db.get_latest_recipe(ref)
@@ -129,6 +143,7 @@ class PkgCache:
 
     def pkg_layout(self, pref: PkgReference):
         """ the revision must exists, the folder must exist
+        No longer used by GraphBinariesAnalyzer
         """
         assert pref.ref.revision, "Recipe revision must be known to get the package layout"
         assert pref.package_id, "Package id must be known to get the package layout"
@@ -138,6 +153,23 @@ class PkgCache:
         # we use abspath to convert cache forward slash in Windows to backslash
         return PackageLayout(pref, os.path.abspath(os.path.join(self._base_folder, pref_path)))
 
+    def pkg_layout_latest(self, pref: PkgReference):
+        """
+        GraphBinariesAnalyzer will call this method to avoid doing 2 DB calls, previously
+        it was using pkg_layout() after a get_latest_package_revision()
+        """
+        assert pref.ref.revision, "Recipe revision must be known to get the package layout"
+        assert pref.package_id, "Package id must be known to get the package layout"
+        assert pref.revision is None
+
+        pref_data = self._db.get_latest_package_reference_data(pref)
+        if pref_data is None:
+            return None
+        pref_path = pref_data.get("path")
+        pref = pref_data.get("pref")  # new revision with timestamp
+        # we use abspath to convert cache forward slash in Windows to backslash
+        return PackageLayout(pref, os.path.abspath(os.path.join(self._base_folder, pref_path)))
+
     def create_ref_layout(self, ref: RecipeReference):
         """ called exclusively by:
         - RemoteManager.get_recipe()
@@ -151,8 +183,7 @@ class PkgCache:
 
     def create_pkg_layout(self, pref: PkgReference):
         """ called by:
-         - RemoteManager.get_package()
-         - cacje restpre
+         - cache restore
         """
         assert pref.ref.revision, "Recipe revision must be known to create the package layout"
         assert pref.package_id, "Package id must be known to create the package layout"
@@ -162,6 +193,23 @@ class PkgCache:
         self._create_path(package_path, remove_contents=False)
         return PackageLayout(pref, os.path.join(self._base_folder, package_path))
 
+    def get_random_path(self):
+        random_id = str(uuid.uuid4())
+        # d=downloading area. Using short hashes to avoid lengthy paths with hyphens
+        return os.path.join(self._base_folder, "d", self._short_hash_path(random_id))
+
+    def create_atomic_pkg_layout(self, pref: PkgReference, current_folder):
+        """ called by:
+         - RemoteManager.get_package()
+        """
+        assert pref.ref.revision, "Recipe revision must be known to create the package layout"
+        assert pref.package_id, "Package id must be known to create the package layout"
+        assert pref.revision, "Package revision should be known to create the package layout"
+        package_path = self._get_path_pref(pref)
+        path = self._full_path(package_path)
+        atomic_replace(current_folder, path, f"{pref.repr_notime()} package")
+        self._db.create_package(package_path, pref, None)
+
     def update_recipe_timestamp(self, ref: RecipeReference):
         """ when the recipe already exists in cache, but we get a new timestamp from a server
         that would affect its order in our cache """
@@ -184,6 +232,8 @@ class PkgCache:
         return self._db.exists_prev(pref)
 
     def get_latest_package_revision(self, pref: PkgReference) -> PkgReference:
+        # This is no longer needed by the Graph resolution functionality, only by ListAPI
+        # its usage in graph resolution has been replaced by a single call to pkg_layout_latest()
         return self._db.get_latest_package_reference(pref)
 
     def get_package_references(self, ref: RecipeReference,
@@ -269,14 +319,14 @@ class PkgCache:
     def get_recipe_lru(self, ref):
         return self._db.get_recipe_lru(ref)
 
-    def update_recipe_lru(self, ref):
-        self._db.update_recipe_lru(ref)
+    def update_recipes_lru(self, refs):
+        self._db.update_recipes_lru(refs)
 
     def get_package_lru(self, pref):
         return self._db.get_package_lru(pref)
 
-    def update_package_lru(self, pref):
-        self._db.update_package_lru(pref)
+    def update_packages_lru(self, prefs):
+        self._db.update_packages_lru(prefs)
 
     def path_to_ref(self, path):
         try:
