@@ -1,6 +1,5 @@
 import os
 import textwrap
-from email.policy import default
 
 from jinja2 import Template, StrictUndefined
 
@@ -9,11 +8,12 @@ from conan.internal import check_duplicated_generator
 from conan.internal.internal_tools import raise_on_universal_arch
 from conan.tools.apple.apple import is_apple_os, apple_min_version_flag, \
     resolve_apple_flags, apple_extra_flags
-from conan.tools.build.cross_building import cross_building
-from conan.tools.build.flags import architecture_link_flag, libcxx_flags, architecture_flag, threads_flags
+from conan.tools.build.cross_building import cross_building, can_run
+from conan.tools.build.flags import (architecture_link_flag, libcxx_flags, architecture_flag,
+                                     threads_flags)
 from conan.tools.env import VirtualBuildEnv
-from conan.tools.meson.helpers import *
-from conan.tools.meson.helpers import get_apple_subsystem
+from conan.tools.meson.helpers import get_apple_subsystem, to_cppstd_flag, to_cstd_flag, \
+    to_meson_machine, to_meson_value
 from conan.tools.microsoft import VCVars, msvc_runtime_flag
 from conan.internal.util.files import save
 
@@ -175,9 +175,9 @@ class MesonToolchain:
         build_type = self._conanfile.settings.get_safe("build_type")
         #: Build type to use.
         self.buildtype = {"Debug": "debug",  # Note, it is not "'debug'"
-                           "Release": "release",
-                           "MinSizeRel": "minsize",
-                           "RelWithDebInfo": "debugoptimized"}.get(build_type, build_type)
+                          "Release": "release",
+                          "MinSizeRel": "minsize",
+                          "RelWithDebInfo": "debugoptimized"}.get(build_type, build_type)
         #: Disable asserts.
         self.b_ndebug = "true" if self.buildtype != "debug" else "false"
 
@@ -201,9 +201,9 @@ class MesonToolchain:
         cppstd = self._conanfile.settings.get_safe("compiler.cppstd")
         cstd = self._conanfile.settings.get_safe("compiler.cstd")
         #: C++ language standard to use. Defined by ``to_cppstd_flag()`` by default.
-        self.cpp_std = to_cppstd_flag(compiler, compiler_version, cppstd)
+        self.cpp_std = to_cppstd_flag(self._conanfile, compiler, compiler_version, cppstd)
         #: C language standard to use. Defined by ``to_cstd_flag()`` by default.
-        self.c_std = to_cstd_flag(cstd)
+        self.c_std = to_cstd_flag(self._conanfile, cstd)
         #: VS runtime library to use. Defined by ``msvc_runtime_flag()`` by default.
         self.b_vscrt = None
         if compiler in ("msvc", "clang"):
@@ -266,7 +266,8 @@ class MesonToolchain:
                 sdk_host = conanfile.settings.get_safe("os.sdk")
                 self.cross_build["host"]["subsystem"] = get_apple_subsystem(sdk_host)
                 self.cross_build["build"]["subsystem"] = get_apple_subsystem(sdk_build)
-            self.properties["needs_exe_wrapper"] = True
+            # Issue: https://github.com/conan-io/conan/issues/19217
+            self.properties["needs_exe_wrapper"] = not can_run(self._conanfile)
             if hasattr(conanfile, 'settings_target') and conanfile.settings_target:
                 settings_target = conanfile.settings_target
                 os_target = settings_target.get_safe("os")
@@ -289,8 +290,6 @@ class MesonToolchain:
 
         # Read configuration for sys_root property (honoring existing conf)
         self._sys_root = self._conanfile_conf.get("tools.build:sysroot", check_type=str)
-        if self._sys_root:
-            self.properties["sys_root"] = self._sys_root
 
         # Read configuration for compilers
         compilers_by_conf = self._conanfile_conf.get("tools.build:compiler_executables", default={},
@@ -414,7 +413,6 @@ class MesonToolchain:
         self.apple_isysroot_flag = isysroot_flag.split() if isysroot_flag else []
         self.apple_min_version_flag = [apple_min_version_flag(self._conanfile)]
         # Objective C/C++ ones
-        flags = []
         self.objc = compilers_by_conf.get("objc", "clang")
         self.objcpp = compilers_by_conf.get("objcpp", "clang++")
         enable_arc = self._conanfile.conf.get("tools.apple:enable_arc", check_type=bool)
@@ -439,36 +437,42 @@ class MesonToolchain:
 
         arch = self._conanfile.settings.get_safe("arch")
         os_build = self.cross_build["build"]["system"]
-        ndk_bin = os.path.join(ndk_path, "toolchains", "llvm", "prebuilt", "{}-x86_64".format(os_build), "bin")
+        ndk_bin = os.path.join(ndk_path, "toolchains",
+                               "llvm", "prebuilt", "{}-x86_64".format(os_build), "bin")
         android_api_level = self._conanfile.settings.get_safe("os.api_level")
         android_target = {'armv7': 'armv7a-linux-androideabi',
                           'armv8': 'aarch64-linux-android',
                           'x86': 'i686-linux-android',
                           'x86_64': 'x86_64-linux-android'}.get(arch)
         os_build = self._conanfile.settings_build.get_safe('os')
-        compiler_extension = ".cmd" if os_build == "Windows" else ""
+        compile_ext = ".cmd" if os_build == "Windows" else ""
         # User has more prio than Conan
-        self.c = os.path.join(ndk_bin, "{}{}-clang{}".format(android_target, android_api_level, compiler_extension))
-        self.cpp = os.path.join(ndk_bin, "{}{}-clang++{}".format(android_target, android_api_level, compiler_extension))
+        self.c = os.path.join(ndk_bin, f"{android_target}{android_api_level}-clang{compile_ext}")
+        self.cpp = os.path.join(ndk_bin, f"{android_target}{android_api_level}-clang++{compile_ext}")
         self.ar = os.path.join(ndk_bin, "llvm-ar")
 
     def _get_extra_flags(self):
         # Now, it's time to get all the flags defined by the user
         cxxflags = self._conanfile_conf.get("tools.build:cxxflags", default=[], check_type=list)
         cflags = self._conanfile_conf.get("tools.build:cflags", default=[], check_type=list)
-        sharedlinkflags = self._conanfile_conf.get("tools.build:sharedlinkflags", default=[], check_type=list)
-        exelinkflags = self._conanfile_conf.get("tools.build:exelinkflags", default=[], check_type=list)
-        linker_scripts = self._conanfile_conf.get("tools.build:linker_scripts", default=[], check_type=list)
-        linker_script_flags = ['-T"' + linker_script + '"' for linker_script in linker_scripts]
+        sharedlinkflags = self._conanfile_conf.get("tools.build:sharedlinkflags", default=[],
+                                                   check_type=list)
+        exelinkflags = self._conanfile_conf.get("tools.build:exelinkflags", default=[],
+                                                check_type=list)
+        linker_scripts = self._conanfile_conf.get("tools.build:linker_scripts", default=[],
+                                                  check_type=list)
+        linker_script_flags = ['-T' + linker_script for linker_script in linker_scripts]
         defines = self._conanfile_conf.get("tools.build:defines", default=[], check_type=list)
         sys_root = [f"--sysroot={self._sys_root}"] if self._sys_root else [""]
-        ld = sharedlinkflags + exelinkflags + linker_script_flags + sys_root + self.extra_ldflags + self.threads_flags
+        ld = (sharedlinkflags + exelinkflags + linker_script_flags + sys_root + self.extra_ldflags
+              + self.threads_flags)
         # Apple extra flags from confs (visibilty, bitcode, arc)
         cxxflags += self.apple_extra_flags
         cflags += self.apple_extra_flags
         ld += self.apple_extra_flags
         return {
-            "cxxflags": [self.arch_flag] + cxxflags + sys_root + self.extra_cxxflags + self.threads_flags,
+            "cxxflags": [self.arch_flag] + cxxflags + sys_root + self.extra_cxxflags
+                        + self.threads_flags,
             "cflags": [self.arch_flag] + cflags + sys_root + self.extra_cflags + self.threads_flags,
             "ldflags": [self.arch_flag] + [self.arch_link_flag] + ld,
             "defines": [f"-D{d}" for d in (defines + self.extra_defines)]
@@ -508,6 +512,11 @@ class MesonToolchain:
         self.objc_link_args.extend(self.c_link_args)
         self.objcpp_link_args.extend(self.cpp_link_args)
 
+        if self.preprocessor_definitions:
+            self._conanfile.output.warning(
+                "Use 'extra_defines' attribute for compiler preprocessor definitions instead " +
+                "of 'preprocessor_definitions'", warn_tag="deprecated")
+
         if self.libcxx:
             self.cpp_args.append(self.libcxx)
             self.cpp_link_args.append(self.libcxx)
@@ -565,6 +574,7 @@ class MesonToolchain:
             "objcpp_link_args": to_meson_value(self._filter_list_empty_fields(self.objcpp_link_args)),
             "pkg_config_path": self.pkg_config_path,
             "build_pkg_config_path": self.build_pkg_config_path,
+            #: Deprecated: Dict-like object that defines Meson ``preprocessor definitions``. Use the extra_defines attribute instead.
             "preprocessor_definitions": self.preprocessor_definitions,
             "cross_build": self.cross_build,
             "is_apple_system": self._is_apple_system
